@@ -5,7 +5,8 @@ from typing import Sequence, Union
 from .snowflake import get_snowflake_id
 from .support import DBError, NotFoundError
 from . import db, log_support, transaction, orm_support, Dialect
-from .constant import LIMIT_1, NO_LIMIT, DEFAULT_KEY_FIELD, KEY, SELECT_KEY, TABLE, UPDATE_BY, UPDATE_TIME, DEL_FLAG, KEY_STRATEGY
+from .constant import LIMIT_1, NO_LIMIT, DEFAULT_KEY_FIELD, KEY, SELECT_KEY, TABLE, UPDATE_BY, UPDATE_TIME, DEL_FLAG, \
+    KEY_STRATEGY, KEY_SEQ
 
 
 class DelFlag(IntEnum):
@@ -209,8 +210,10 @@ class Model:
             select_key = cls._get_select_key()
             if not select_key:
                 try:
-                    select_key = Dialect.get_select_key(table=table, key=key)
+                    select_key = Dialect.get_select_key(keq_seq=cls._get_key_seq(), table=table, key=key)
                 except NotImplementedError:
+                    if Dialect.curr_engine() == db.Engine.POSTGRESQL:
+                        raise DBError(f"Expect 'key_seq' or 'select_key'. you can set it in model class with '__key_seq__' or '__select_key__'.")
                     raise DBError(f"Expect 'select_key'. you can set it in model class with '__select_key__'.")
             return db.save_select_key(select_key, table, **kwargs)
 
@@ -355,7 +358,7 @@ class Model:
 
         return db.batch_insert(table, *args)
 
-    # ------------------------------------------------Class query method--------------------------------------------------------
+    # ------------------------------------------------Class query method------------------------------------------------
     @classmethod
     def count(cls, **kwargs):
         """
@@ -590,7 +593,7 @@ class Model:
             return {k: v for k, v in self.__dict__.items() if v is not None}
         return {k: v for k, v in self.__dict__.items()}
 
-    # ------------------------------------------------Private class method------------------------------------------------------------------
+    # ------------------------------------------------Private class method----------------------------------------------
     @classmethod
     def _logical_delete_by_id_op(cls, _id: Union[int, str], update_by: Union[int, str] = None, del_status=DelFlag.DELETED):
         key, table = cls._get_key_and_table()
@@ -652,9 +655,11 @@ class Model:
 
     @classmethod
     def _get_select_key(cls):
-        if hasattr(cls, SELECT_KEY):
-            return cls.__select_key__
-        return None
+        return cls.__select_key__ if hasattr(cls, SELECT_KEY) else None
+
+    @classmethod
+    def _get_key_seq(cls):
+        return cls.__key_seq__ if hasattr(cls, KEY_SEQ) else None
 
     @classmethod
     def get_table(cls):
